"""TODO: doc module"""


from unittest import TestCase



class TestModule(TestCase):
    """TODO: doc class"""

    def __init__(self, method_name='TestModule'):
        super(TestModule, self).__init__(method_name)

    def test_000_dummytest(self):
        """TODO: doc method"""
        print("Library must can be installed, but not really tested")
